@@ -13,15 +13,16 @@
 package Directory::Queue::Normal;
 use strict;
 use warnings;
-our $VERSION  = "1.7";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.8";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
 #
 
-use Directory::Queue qw(_name ST_MTIME ST_NLINK /Regexp/ /file/ /special/);
+use Directory::Queue qw(_name /Regexp/ /file/ /special/);
 use No::Worries::Die qw(dief);
+use No::Worries::Stat qw(ST_MTIME ST_NLINK);
 use No::Worries::Warn qw(warnf);
 use POSIX qw(:errno_h);
 
@@ -780,6 +781,12 @@ following attributes are supported:
 
 the queue toplevel directory (mandatory)
 
+=item rndhex
+
+the "random" hexadecimal digit to use in element names (aka I<R>) as a
+number between 0 and 15
+(default: randomly generated)
+
 =item umask
 
 the umask to use when creating files and directories
@@ -972,7 +979,7 @@ represents the microsecond part of the time since the Epoch
 
 =item I<R>
 
-is a random digit used to reduce name collisions
+is a random hexadecimal digit used to reduce name collisions
 
 =back
 
@@ -988,4 +995,4 @@ L<Directory::Queue>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright CERN 2010-2012
+Copyright (C) CERN 2010-2013
